@@ -1,4 +1,4 @@
-set rcsId {$Id: confint.tcl,v 1.28 1998/02/07 10:32:44 jfontain Exp $}
+set rcsId {$Id: confint.tcl,v 1.29 1998/09/27 20:45:52 jfontain Exp $}
 
 # minimalist composite widget configuration interface for widget testing and HTML live documentation with configuration applet
 
@@ -17,7 +17,7 @@ proc configurationInterface::configurationInterface {this parentPath args} compo
     new widgetTip -path $composite::($this,names,path) -text {select component(class)}
     pack $composite::($this,names,path) -side left -anchor nw
     pack $composite::($this,container,path) -padx 2 -pady 2 -fill both -expand 1
-    composite::manage $this [new scroller $composite::($this,bottom,path)] scroller
+    composite::manage $this [new scroller $composite::($this,bottom,path) -height 100] scroller
     pack $composite::($this,scroller,path) -fill both
 
     composite::complete $this
